#!/usr/bin/tclsh

exec elegant xyz.ele >@ stdout

set xyz "results/xyz.sdds"

set plain "results/draft.plain"
set f [open $plain w+]

foreach {X Z theta ElementType ElementName} [exec sdds2stream $xyz -col=X,Z,theta,ElementType,ElementName] {
    set nz [expr {-sin($theta)}]
    set nx [expr { cos($theta)}]

    if       {$ElementType == "QUAD"} {
	set width 0.4
    } elseif {$ElementType == "SBEN"} {
	set width 0.5
    } elseif {$ElementType == "HKICK"} {
	set width 0.1
    } elseif {$ElementType == "RFCA"} {
	set width 0.3
    } elseif {$ElementType == "MONI"} {
	set width 0.2
    } else {
	set width 0
    }

    if {$width > 0} {
	set z $Z
	set x $X
	puts $f "$x $z $ElementType $ElementName"

	set z [expr {$Z+$nz*$width/2}]
	set x [expr {$X+$nx*$width/2}]
	puts $f "$x $z $ElementType $ElementName"

	set z [expr {$last_Z+$last_nz*$width/2}]
	set x [expr {$last_X+$last_nx*$width/2}]
	puts $f "$x $z $ElementType $ElementName"

	set z [expr {$last_Z-$last_nz*$width/2}]
	set x [expr {$last_X-$last_nx*$width/2}]
	puts $f "$x $z $ElementType $ElementName"

	set z [expr {$Z-$nz*$width/2}]
	set x [expr {$X-$nx*$width/2}]
	puts $f "$x $z $ElementType $ElementName"

	set z $Z
	set x $X
	puts $f "$x $z $ElementType $ElementName"
    }
    set last_X $X
    set last_Z $Z
    set last_nx $nx
    set last_nz $nz
}

close $f

set draft "results/draft.sdds"
exec \
    plaindata2sdds $plain -pipe=out -noRowCount -outputMode=ascii \
	-col=X,float,units=m \
        -col=Z,float,units=m \
	-col=ElementType,string \
	-col=ElementName,string | \
    sddsbreak -pipe=in $draft -changeof=ElementName

file delete -force $plain

exec tclsh plot_element_names.tcl &

