#!/usr/bin/tclsh

set xyz   "results/xyz.sdds"
set draft "results/draft.sdds"

set lines [exec \
    sddsbreak $xyz -pipe=out -changeOf=ElementName | \
    sddsprocess -pipe -fclip=0.5,0 | \
    sddsprocess -pipe -clip=1,0,invert | \
    sdds2stream -pipe=in -col=X,Z,theta,ElementType,ElementName]

set tmp "results/pointers.plain"
set pointers "results/pointers.sdds"
set f [open $tmp w+]
set str ""
foreach {X Z theta ElementType ElementName} $lines {
    if       {$ElementType == "SBEN"} {
        set pointer_length +1.1
    } elseif {$ElementType == "QUAD"} {
	if {[string range $ElementName 1 1] == "F"} {
	    set pointer_length -0.8
	} else {
	    set pointer_length -1.2
	}
    } elseif {$ElementType == "HKICK"} {
        set pointer_length -1.8
    } elseif {$ElementType == "VKICK"} {
        set pointer_length -0.8
    } elseif {$ElementType == "MONI"} {
        set pointer_length +1.4
    } else {
        set pointer_length 0
    }

    set nz [expr {-sin($theta)}]
    set nx [expr { cos($theta)}]
    set x [expr {$Z+$nz*$pointer_length}]
    set y [expr {$X+$nx*$pointer_length}]

    if {$pointer_length != 0} {
	set str "$str \"-str=$ElementName,x=$x,y=$y,sc=0.8\""
	puts $f "$Z $X"
	puts $f "$x $y"
    }
}
close $f

exec \
    plaindata2sdds $tmp -pipe=out -noRowCount -col=Z,float,units=m -col=X,float,units=m -outputMode=ascii | \
    sddsbreak -pipe=in  $pointers -rowlimit=2
file delete -force $tmp

eval exec sddsplot -aspectRatio=1 \
    -column=Z,X -graph=line,type=3,thick=2 -match=col,ElementType=SBEN  -split=page $draft \
    -column=Z,X -graph=line,type=2,thick=2 -match=col,ElementName=?F?   -split=page $draft \
    -column=Z,X -graph=line,type=1,thick=2 -match=col,ElementName=?D?   -split=page $draft \
    -column=Z,X -graph=line,type=4,thick=2 -match=col,ElementType=HKICK -split=page $draft \
    -column=Z,X -graph=line,type=9,thick=2 -match=col,ElementType=RFCA  -split=page $draft \
    -column=Z,X -graph=line,type=0,thick=4 -match=col,ElementType=MONI  -split=page $draft \
    -column=Z,X -graph=line,type=15,thick=1 $xyz \
    -column=Z,X -graph=line,type=1 -split=page $pointers \
    $str \
&
